pub struct StoreReadItemRequest {
pub key: String,
}Fields
key: StringTrait Implementations
Sourceimpl Clone for StoreReadItemRequest
impl Clone for StoreReadItemRequest
Sourcefn clone(&self) -> StoreReadItemRequest
fn clone(&self) -> StoreReadItemRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StoreReadItemRequest> for StoreReadItemRequest
impl CompatFrom<StoreReadItemRequest> for StoreReadItemRequest
Sourcefn compat_from(value: StoreReadItemRequest) -> Self
fn compat_from(value: StoreReadItemRequest) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StoreReadItemRequest> for StoreReadItemRequest
impl CompatFrom<StoreReadItemRequest> for StoreReadItemRequest
Sourcefn compat_from(value: StoreReadItemRequest) -> Self
fn compat_from(value: StoreReadItemRequest) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StoreReadItemRequest
impl Debug for StoreReadItemRequest
Sourceimpl<'a, ___E> Encode<StoreReadItemRequest<'static>, ___E> for &'a StoreReadItemRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<StoreReadItemRequest<'static>, ___E> for &'a StoreReadItemRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StoreReadItemRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StoreReadItemRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StoreReadItemRequest<'static>, ___E> for StoreReadItemRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<StoreReadItemRequest<'static>, ___E> for StoreReadItemRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StoreReadItemRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StoreReadItemRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StoreReadItemRequest<'static>>, ___E> for &'a StoreReadItemRequestwhere
___E: Encoder + ?Sized,
&'a StoreReadItemRequest: Encode<StoreReadItemRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StoreReadItemRequest<'static>>, ___E> for &'a StoreReadItemRequestwhere
___E: Encoder + ?Sized,
&'a StoreReadItemRequest: Encode<StoreReadItemRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StoreReadItemRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StoreReadItemRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StoreReadItemRequest<'static>>, ___E> for StoreReadItemRequest
impl<___E> EncodeOption<Box<'static, StoreReadItemRequest<'static>>, ___E> for StoreReadItemRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StoreReadItemRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StoreReadItemRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StoreReadItemRequest<'de>> for StoreReadItemRequest
impl<'de> FromWire<StoreReadItemRequest<'de>> for StoreReadItemRequest
Sourcefn from_wire(wire: StoreReadItemRequest<'de>) -> Self
fn from_wire(wire: StoreReadItemRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StoreReadItemRequest<'de>> for StoreReadItemRequest
impl<'de> FromWireRef<StoreReadItemRequest<'de>> for StoreReadItemRequest
Sourcefn from_wire_ref(wire: &StoreReadItemRequest<'de>) -> Self
fn from_wire_ref(wire: &StoreReadItemRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StoreReadItemRequest
impl Hash for StoreReadItemRequest
Sourceimpl Ord for StoreReadItemRequest
impl Ord for StoreReadItemRequest
Sourcefn cmp(&self, other: &StoreReadItemRequest) -> Ordering
fn cmp(&self, other: &StoreReadItemRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StoreReadItemRequest
impl PartialEq for StoreReadItemRequest
Sourceimpl PartialOrd for StoreReadItemRequest
impl PartialOrd for StoreReadItemRequest
impl Eq for StoreReadItemRequest
impl StructuralPartialEq for StoreReadItemRequest